export const USER_PREFERENCES_KEYS = {
  CLINICIAN_DASHBOARD_TASKING_TABLE_FILTER: 'clinicianDashboardTaskingTableFilter',
  ENCOUNTER_TAB_ORDERS: 'encounterTabOrders',
  SELECTED_GRAPHED_VITALS_ON_FILTER: 'selectedGraphedVitalsOnFilter',
  SELECTED_GRAPHED_CHARTS_ON_FILTER: 'selectedGraphedChartsOnFilter',
  SELECTED_CHART_TYPE_ID: 'selectedChartTypeId',
  LOCATION_BOOKING_FILTERS: 'locationBookingFilters',
  LOCATION_BOOKING_VIEW_TYPE: 'locationBookingViewType',
  OUTPATIENT_APPOINTMENT_FILTERS: 'outpatientAppointmentFilters',
  OUTPATIENT_APPOINTMENT_GROUP_BY: 'outpatientAppointmentGroupBy',
  LOCATION_ASSIGNMENT_SELECTED_FACILITY: 'locationAssignmentSelectedFacility',
};
